
From: NeilBrown <neilb@cse.unsw.edu.au>

raid5 rebuild takes stripes so agressively that other access cannot get a
look-in.

With this patch, the rebuild pauses slightly if there is a 
shortage of stripes to let other processes have a chance.



---

 25-akpm/drivers/md/raid5.c |    9 ++++++++-
 1 files changed, 8 insertions(+), 1 deletion(-)

diff -puN drivers/md/raid5.c~md-02-rebuild-needs-yield drivers/md/raid5.c
--- 25/drivers/md/raid5.c~md-02-rebuild-needs-yield	Thu Jan 15 17:36:16 2004
+++ 25-akpm/drivers/md/raid5.c	Thu Jan 15 17:36:16 2004
@@ -1395,7 +1395,14 @@ static int sync_request (mddev_t *mddev,
 
 	first_sector = raid5_compute_sector(stripe*data_disks*sectors_per_chunk
 		+ chunk_offset, raid_disks, data_disks, &dd_idx, &pd_idx, conf);
-	sh = get_active_stripe(conf, sector_nr, pd_idx, 0);
+	sh = get_active_stripe(conf, sector_nr, pd_idx, 1);
+	if (sh == NULL) {
+		sh = get_active_stripe(conf, sector_nr, pd_idx, 0);
+		/* make sure we don't swamp the stripe cache if someone else
+		 * is trying to get access 
+		 */
+		yield();
+	}
 	spin_lock(&sh->lock);	
 	set_bit(STRIPE_SYNCING, &sh->state);
 	clear_bit(STRIPE_INSYNC, &sh->state);

_
